'use strict';

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol ? "symbol" : typeof obj; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _request = require('request');

var _request2 = _interopRequireDefault(_request);

var _extend = require('extend');

var _extend2 = _interopRequireDefault(_extend);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var CamperApi = function () {
    function CamperApi(settings, logger) {
        _classCallCheck(this, CamperApi);

        this.baseUrl = 'https://booking.camperdays.de/api/v1';

        if ((typeof settings === 'undefined' ? 'undefined' : _typeof(settings)) !== 'object') {
            return false;
        }

        if (!(this instanceof CamperApi)) {
            return new CamperApi(token);
        }

        this.logger = typeof logger === 'undefined' ? console : logger;

        this.settings = (0, _extend2.default)(true, {
            logErrors: false
        }, settings);

        this.accessToken = settings.accessToken;
    }

    _createClass(CamperApi, [{
        key: '_createRequest',
        value: function _createRequest(options, qs) {

            return {
                method: options.method,
                url: this.baseUrl + options.path,
                qs: qs,
                headers: {
                    'Authorization': 'Basic ' + this.accessToken,
                    'Accept': 'application/json'
                },
                timeout: 1500,
                body: options.body,
                json: true
            };
        }
    }, {
        key: '_executeRequest',
        value: function _executeRequest(options, querystring, callback) {
            var _this = this;

            if (!callback) {
                callback = querystring;
                querystring = undefined;
            }

            var req = this._createRequest(options, querystring);

            (0, _request2.default)(req, function (err, response, body) {

                if (_this.settings.logErrors) {
                    _this.log(req.url, err);
                }

                if (!body) {
                    return callback(null, null);
                }

                if (!err) {
                    return callback(body.error, body.result || null);
                }

                callback(err, null);
            });
        }

        /**
         * Log Errors.
         *
         * GET /destination
         * @param name STRING
         * @param err {errorObject}
        */

    }, {
        key: 'log',
        value: function log(name, err) {

            if (!err) {
                return null;
            }

            if (err && err.code === 'ETIMEDOUT') {

                if (err.connect === true) {
                    return this.logger.error('ApiCall | %s | Request connection timeout', name);
                }

                this.logger.error('ApiCall | %s | Request timeout', name);
            }
        }

        /**
         * Returns a destination object.
         *
         * GET /destination
         * @param callback {requestCallback} The callback that will manage the response.
        */

    }, {
        key: 'destination',
        value: function destination(callback) {

            this._executeRequest({
                method: 'GET',
                path: '/destination'
            }, callback);
        }

        /**
         * Returns a search object.
         *
         * POST /search
         * @param searchData {object} search request data
         * @param callback {requestCallback} The callback that will manage the response.
        */

    }, {
        key: 'search',
        value: function search(searchData, callback) {

            this._executeRequest({
                method: 'POST',
                body: searchData,
                path: '/search'
            }, callback);
        }

        /**
         * Returns a result object.
         *
         * GET /search/:requestId/offer
         * @param requestId {string} result list identifier
         * @param callback {requestCallback} The callback that will manage the response.
        */

    }, {
        key: 'result',
        value: function result(requestId, callback) {

            this._executeRequest({
                method: 'GET',
                path: '/search/' + requestId + '/offer'
            }, callback);
        }

        /**
         * Returns a offer object.
         *
         * GET /search/:requestId/offer
         * @param requestId {string} restrict the set of offers
         * @param offerId {string} offer identifier
         * @param callback {requestCallback} The callback that will manage the response.
        */

    }, {
        key: 'offer',
        value: function offer(requestId, offerId, callback) {

            this._executeRequest({
                method: 'GET',
                path: '/search/' + requestId + '/offer/' + offerId
            }, callback);
        }

        /**
         * Returns a booking object.
         *
         * POST /booking
         * @param bookingData {object} bookingData
         * @param callback {requestCallback} The callback that will manage the response.
        */

    }, {
        key: 'booking',
        value: function booking(bookingData, callback) {

            this._executeRequest({
                method: 'POST',
                body: bookingData,
                path: '/booking'
            }, callback);
        }
    }]);

    return CamperApi;
}();

module.exports = CamperApi;
